﻿using System;
using System.Drawing;
using Telerik.WinControls.Enumerations;
using Telerik.WinControls.UI;

namespace CheckedGroupHeaderCellElement
{
    public class CustomGroupHeaderCell : GridGroupContentCellElement
    {
        public event EventHandler MeCheckChanged;

        private RadCheckBoxElement checkbox;

        public CustomGroupHeaderCell(GridViewColumn column, GridRowElement row)
            : base(column, row)
        {
            this.DrawText = false;
        }

        protected override Type ThemeEffectiveType
        {
            get
            {
                return typeof(GridGroupContentCellElement);
            }
        }

        protected override void CreateChildElements()
        {
            base.CreateChildElements();
            checkbox = new RadCheckBoxElement();
            checkbox.MinSize = new System.Drawing.Size(5, 5);
            checkbox.ToggleStateChanged += new StateChangedEventHandler(checkbox_ToggleStateChanged);
            Children.Insert(0, checkbox);
        }

        protected override void SetContentCore(object value)
        {
            base.SetContentCore(value);

            if (this.RowInfo.Tag != null)
            {
                this.checkbox.ToggleState = (bool)this.RowInfo.Tag ? ToggleState.On : ToggleState.Off;
            }
            else
            {
                this.checkbox.ToggleState = ToggleState.Off;
            }

            this.checkbox.TextElement.Text = this.Text;
        }

        private void checkbox_ToggleStateChanged(object sender, StateChangedEventArgs args)
        {
            if (MeCheckChanged != null)
                MeCheckChanged(this, null);

            this.RowInfo.Tag = this.checkbox.ToggleState == ToggleState.On;
        }

        protected override System.Drawing.SizeF ArrangeOverride(System.Drawing.SizeF finalSize)
        {
            SizeF size = base.ArrangeOverride(finalSize);
            RectangleF rect = this.GetClientRectangle(finalSize);

            if (this.checkbox != null)
            {
                this.checkbox.Arrange(new RectangleF(rect.Width / 2 - this.checkbox.DesiredSize.Width / 2,
                                                     rect.Top + (rect.Height - this.checkbox.DesiredSize.Height) / 2,
                                                     this.checkbox.DesiredSize.Width,
                                                     this.checkbox.DesiredSize.Height));
            }

            return size;
        }

    }
}
